Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9756)

Unified Diff: chrome/common/extensions/extension_constants.h

Issue 10532037: Revert r139371 and r138961 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/webstore_installer.cc ('k') | chrome/common/extensions/extension_constants.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/extension_constants.h
diff --git a/chrome/common/extensions/extension_constants.h b/chrome/common/extensions/extension_constants.h
index 7b3143de13273b79a9b2f26a9932722d79412ccf..f383801793eaf2ef6088fa9711feae453c71b797 100644
--- a/chrome/common/extensions/extension_constants.h
+++ b/chrome/common/extensions/extension_constants.h
@@ -31,11 +31,12 @@ namespace extension_urls {
// etc.) about an extension from the webstore as JSON.
GURL GetWebstoreItemJsonDataURL(const std::string& extension_id);
- // Return the update URL used by gallery/webstore extensions/apps.
- GURL GetWebstoreUpdateUrl();
+ // Return the update URL used by gallery/webstore extensions/apps. The
+ // |secure| parameter will be ignored if the update URL is overriden with
+ // --apps-gallery-update-url.
+ GURL GetWebstoreUpdateUrl(bool secure);
- // Returns whether the URL is the webstore update URL (just considering host
- // and path, not scheme, query, etc.)
+ // Returns whether the URL is the webstore update URL (secure or not).
bool IsWebstoreUpdateUrl(const GURL& update_url);
// Returns true if the URL points to an extension blacklist.
« no previous file with comments | « chrome/browser/extensions/webstore_installer.cc ('k') | chrome/common/extensions/extension_constants.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698